==> webgen-0.9.tgz: webgen-0.9/postbbs.php <==
<?php
 /***********************************************************
  ثeG 0.7
 *************************************************************/
 require("user.php");
 require("$configfile");
 require("dbconfig.php");
 require("authgen.php");
 require("procpic.php");
 require("http_post.php");
 /*****BzJܼ *************/
 $key=$_REQUEST["key"];
 $day1=$_REQUEST["day1"];
 $day2=$_REQUEST["day2"];
 $user=$_REQUEST["user"];
 /****** ]wBBSiKѼ *******/
 $BBSPOST="http://wbbs.fhl.net/php/post.php";
 /*****	XnͪM *******/
   $QUERY="select ptab,pname,ctlfile,target,boards from main where ptab like '$key%'";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
        echo "MƬd߿~AO $QUERY !";
        exit;
   }
   $numrow=db_NumRows($result);
   if ($numrow==0){
        echo "$key MƬdߨS!<br>\n";
        exit;
   }
   if ($day1>$day2) //SWAP
   {
	$tmp=$day1;
	$day1=$day2;
	$day2=$tmp;
   }
   /****BzC@ӱM****/
   for ($i=0;$i<$numrow;$i++)
   {
   	$ARAW=db_fetch_row($result,$i); //Ū@MyzɰO
	if (strlen(trim($ARAW[4]))==0) continue; //pGSgboardsANLC
        $P_BOAR=split(",",$ARAW[4]);
	$prjq="select aid,title,author,pubtime,abst,txt,email,username,ip,modtime from $ARAW[0] where pubtime>='$day1' and pubtime<='$day2' order by pubtime DESC";
   	$res=db_exec($db_conn,$prjq);
   	if (!$res){
        	echo "MƬd߿~AO $prjq !<br>\n";
        	exit;
   	}
   	$numr=db_NumRows($res); //onBz峹
   	if ($numr==0){
        	echo "$ARAW[0] MS峹I<br>\n";
		db_freeresult($res);
		continue;
   	}
   	for ($j=0;$j<$numr;$j++) //]M椺C@g峹
   	{
                $PARAW=db_fetch_row($res,$j); //Ū@M峹O
	/********************BzJϧΪD****************/
                $PARAW[4]=procpic($PARAW[4],trim($ARAW[3]),0); //abst
                $PARAW[5]=procpic($PARAW[5],trim($ARAW[3]),0); //txt
	    $PARAW[5]=str_replace("<br>\n","\n",$PARAW[5]);
	    $PARAW[5]=str_replace("<br>","\n",$PARAW[5]);
	    for ($k=0;$k<count($P_BOAR);$k++) //C@ӰQװ
	    {
	    	$bbs=new http_post;
	    	$bbs->set_action($BBSPOST);
	    	$bbs->set_enctype("multipart/form-data");
            	echo "$ARAW[0] <font color=\"red\">M</font> $PARAW[2] <font color=\"red\"></font> $PARAW[1]<font color=\"red\"> K</font> $P_BOAR[$k] <br>\n";
	    	$bbs->set_element("title1",trim($PARAW[1]));//D
	    	$bbs->set_element("board1",trim($P_BOAR[$k]));//Qװ
	    	$bbs->set_element("LOCALSAVE","1");//]wH
	    	$bbs->set_element("SIGNYN","0");//]wñW
	    	$bbs->set_element("WHERE","0");//Qװ
	    	$bbs->set_element("TARGET","0");//Qװ
	    	$bbs->set_element("comment1","@: ".trim($PARAW[2])."\n\n".trim($PARAW[5]));//峹
	    	$bbs->set_element("WEWRdffaf","!!!!!!!!");//峹
	    	$bbs->set_element("RSDfdFDfp",$BBSUSER);//iKH
	    	$bbs->set_element("submit1","iK");//峹
	    	$bbs->set_timeout(100);
	    	$bbs->send(0);
	    	unset($bbs);
	    	sleep(2);
	    } //C@ӰQװ
	} // for numr M椤C@g峹
    } //BzCӱM
  echo "<br>BBSiK! <a href=\"listmain.php?user={$user}\">^</a>";
?>

==> webgen-0.81.tgz: webgen-0.81/postbbs.php <==
<?php
 /***********************************************************
  ثeG 0.7
 *************************************************************/
 require("user.php");
 require("$configfile");
 require("dbconfig.php");
 require("authgen.php");
 require("procpic.php");
 require("http_post.php");
 /*****BzJܼ *************/
 $key=$_REQUEST["key"];
 $day1=$_REQUEST["day1"];
 $day2=$_REQUEST["day2"];
 $user=$_REQUEST["user"];
 /****** ]wBBSiKѼ *******/
 $BBSPOST="http://wbbs.fhl.net/php/post.php";
 /*****	XnͪM *******/
   $QUERY="select ptab,pname,ctlfile,target,boards from main where ptab like '$key%'";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
        echo "MƬd߿~AO $QUERY !";
        exit;
   }
   $numrow=db_NumRows($result);
   if ($numrow==0){
        echo "$key MƬdߨS!<br>\n";
        exit;
   }
   if ($day1>$day2) //SWAP
   {
	$tmp=$day1;
	$day1=$day2;
	$day2=$tmp;
   }
   /****BzC@ӱM****/
   for ($i=0;$i<$numrow;$i++)
   {
   	$ARAW=db_fetch_row($result,$i); //Ū@MyzɰO
	if (strlen(trim($ARAW[4]))==0) continue; //pGSgboardsANLC
        $P_BOAR=split(",",$ARAW[4]);
	$prjq="select aid,title,author,pubtime,abst,txt,email,username,ip,modtime from $ARAW[0] where pubtime>='$day1' and pubtime<='$day2' order by pubtime DESC";
   	$res=db_exec($db_conn,$prjq);
   	if (!$res){
        	echo "MƬd߿~AO $prjq !<br>\n";
        	exit;
   	}
   	$numr=db_NumRows($res); //onBz峹
   	if ($numr==0){
        	echo "$ARAW[0] MS峹I<br>\n";
		db_freeresult($res);
		continue;
   	}
   	for ($j=0;$j<$numr;$j++) //]M椺C@g峹
   	{
                $PARAW=db_fetch_row($res,$j); //Ū@M峹O
	/********************BzJϧΪD****************/
                $PARAW[4]=procpic($PARAW[4],trim($ARAW[3]),0); //abst
                $PARAW[5]=procpic($PARAW[5],trim($ARAW[3]),0); //txt
	    $PARAW[5]=str_replace("<br>\n","\n",$PARAW[5]);
	    $PARAW[5]=str_replace("<br>","\n",$PARAW[5]);
	    for ($k=0;$k<count($P_BOAR);$k++) //C@ӰQװ
	    {
	    	$bbs=new http_post;
	    	$bbs->set_action($BBSPOST);
	    	$bbs->set_enctype("multipart/form-data");
            	echo "$ARAW[0] <font color=\"red\">M</font> $PARAW[2] <font color=\"red\"></font> $PARAW[1]<font color=\"red\"> K</font> $P_BOAR[$k] <br>\n";
	    	$bbs->set_element("title1",trim($PARAW[1]));//D
	    	$bbs->set_element("board1",trim($P_BOAR[$k]));//Qװ
	    	$bbs->set_element("LOCALSAVE","1");//]wH
	    	$bbs->set_element("SIGNYN","0");//]wñW
	    	$bbs->set_element("WHERE","0");//Qװ
	    	$bbs->set_element("TARGET","0");//Qװ
	    	$bbs->set_element("comment1","@: ".trim($PARAW[2])."\n\n".trim($PARAW[5]));//峹
	    	$bbs->set_element("pfsdaFD9SDaf","!2345");//峹
	    	$bbs->set_element("RP#31VDfp",$BBSUSER);//iKH
	    	$bbs->set_element("submit1","iK");//峹
	    	$bbs->set_timeout(100);
	    	$bbs->send(0);
	    	unset($bbs);
	    	sleep(2);
	    } //C@ӰQװ
	} // for numr M椤C@g峹
    } //BzCӱM
  echo "<br>BBSiK! <a href=\"listmain.php?user={$user}\">^</a>";
?>
